@@ -12,6 +12,8 @@ logging.basicConfig(level=logging.DEBUG)
 
 logger = logging.getLogger("dnnevo")
 
+MASTER_ADDRESS = "http://master:5001"
+
 
 class DatasetDescriptor(object):
 
@@ -55,7 +57,7 @@ class DatasetDescriptor(object):
 
 
 class DataStoreClient(object):
-    def __init__(self, dataset_name, indices=None, batch_size=1, is_train=True, dir="./", is_local=True):
+    def __init__(self, dataset_name, indices=None, batch_size=1, is_train=True, dir="./"):
         if indices is None or indices == []:
             self.indices = list(range(10000))
         else:
@@ -65,7 +67,7 @@ class DataStoreClient(object):
         self.prefix = self.dataset_name + "_"
         self.suffix = "_" + ("train" if is_train else "test")
         self.dir = dir
-        self.is_local = is_local
+        self._size = None
 
     def format_id(self, id):
         if len(id.split("_")) > 1:
@@ -78,40 +80,39 @@ class DataStoreClient(object):
             yield l[i:i + n]
 
     def _url(self, url):
-        return ("http://" + url.split(":")[0] if not self.is_local else "http://localhost") + ":" + (url.split(":")[
-                                                                                                         1] if self.is_local else "5000")
+        return "http://" + url
 
-    def get_by_id(self, id):
-        id = str(id)
-        id = self.format_id(id)
-        id_mapping = requests.get('{}/get/'.format(self._url("master:5001")) + id).json()
-        response = requests.get(self._url(id_mapping["worker"]) + "/get/" + id)
+    def get_by_id(self, datapoint_id):
+        datapoint_id = self.format_id(str(datapoint_id))
+        id_mapping = requests.get('{}/get/{}'.format(MASTER_ADDRESS, datapoint_id)).json()
+        response = requests.get('{}/get/{}'.format(self._url(id_mapping["worker"]), datapoint_id))
         try:
             return pickle.loads(response.content)
         except IOError:
-            logger.error("Failed saving result")
+            logger.error("Failed saving result for datapoint id: {}".format(datapoint_id))
             return ""
 
     def get_by_ids(self, ids):
         paths = []
         ids = list(map(lambda x: self.format_id(x), ids))
         for chunk in self._chunks(ids, self.batch_size):
-            response = requests.post('{}/batch/get'.format(self._url("master:5001")),
+            response = requests.post('{}/batch/get'.format(MASTER_ADDRESS),
                                      json.dumps({"ids": chunk}),
                                      headers={'content-type': 'Application/json'})
             batches = response.json()
             for batch in batches:
-                url = self._url(batch["addr"]) + "/batch/get/" + batch["id"]
+                url = "{}/batch/get/{}".format(self._url(batch["addr"]), batch["id"])
                 try:
                     response = requests.get(url)
                     while response.status_code == 202:
                         response = requests.get(url)
                         sleep(5)
                     path = self.dir
-                    with open(path + batch["id"] + ".tar.gz", "wb+") as file:
+                    total_path = path + batch["id"] + ".tar.gz"
+                    with open(total_path, "wb+") as file:
                         file.write(response.content)
-                    subprocess.run(["tar", "-zxvf", path + batch["id"] + ".tar.gz"])
-                    subprocess.run(["rm", path + batch["id"] + ".tar.gz"])
+                    subprocess.run(["tar", "-zxf", total_path])
+                    subprocess.run(["rm", total_path])
                     paths.append(path + batch["id"])
                 except IOError as ex:
                     logger.error("Failed saving result: {}".format(ex))
@@ -128,11 +129,13 @@ class DataStoreClient(object):
         return data, target
 
     def dataset_size(self):
-        response = requests.get('{}/size/{}'.format(self._url("master:5001"), self.dataset_name, self.suffix))
-        return response.json()["size"]
+        if self._size is None:
+            response = requests.get('{}/size/{}/{}'.format(MASTER_ADDRESS, self.dataset_name, self.suffix))
+            self._size = response.json()["size"]
+        return self._size
 
     def get_descriptor(self):
-        response = requests.get('{}/descriptor/{}'.format(self._url("master:5001"), self.dataset_name))
+        response = requests.get('{}/descriptor/{}'.format(MASTER_ADDRESS, self.dataset_name))
         jsn = response.json()
         return DatasetDescriptor(
             self.dataset_name,
